@@ -170,19 +170,24 @@ zypper in -y \
 
 # TBD: have a look at the end of ~/.bashrc
 
-# Farbfunktionen
+# color functions 
 error() { echo -e "\e[91m✖  ERROR: $1\e[0m"; }
 info()  { echo -e "\e[32m✔  INFO:  $1\e[0m"; }
 
 
-info "Updating latex2rtf..."
+info "Updating latex2rtf patched..."
 # install latex2rtf 
 INST_DIR=/opt/latex2rtf
 
-LATEST_VERSION=$(curl -s https://api.github.com/repos/latex2rtf/latex2rtf-sf-files/releases/latest | jq -r .tag_name)
+#LATEST_VERSION=$(curl -s https://api.github.com/repos/latex2rtf/latex2rtf-sf-files/releases/latest | jq -r .tag_name)
+# patch: 
+LATEST_VERSION="2.3.18"
+
+#FILE="$LATEST_VERSION.tar.gz"
+FILE="${LATEST_VERSION}patchedER.tar.gz"
+#URL="https://github.com/latex2rtf/latex2rtf-sf-files/archive/refs/tags/$FILE"
+URL="https://www.simuline.eu/Latex/$FILE"
 
-FILE="$LATEST_VERSION.tar.gz"
-URL="https://github.com/latex2rtf/latex2rtf-sf-files/archive/refs/tags/$LATEST_VERSION.tar.gz"
 DIR="latex2rtf-sf-files-$LATEST_VERSION"
 
 mkdir -p "$INST_DIR"
@@ -202,7 +207,7 @@ pushd "$INST_DIR"
     cd "$DIR"
     make clean 2>/dev/null || true   # falls vorher nichts gebaut wurde, Fehler ignorieren
     # patch needed with newer compiler 
-    sed -i "s/string == '/*string == '/g" convert.c
+    #sed -i "s/string == '/*string == '/g" convert.c
     #sed -i "s@fprintf(stderr, \"%s\", cfg_string)@fprintf(stderr, \"%s\", cfg_string ? cfg_string : \"(null)\")@" open_cfg.c
     make
     make PREFIX="$INST_DIR" install
